:mod:`cybox.common.platform_specification` module
=================================================

.. automodule:: cybox.common.platform_specification
    :members:
    :undoc-members:
    :show-inheritance:
